Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2958)

Unified Diff: cc/layers/picture_layer.cc

Issue 2523673004: [NOT FOR COMMIT] Fully replace SkCanvas uses.
Patch Set: Support Android build. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/layers/picture_layer.h ('k') | cc/layers/picture_layer_impl_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/layers/picture_layer.cc
diff --git a/cc/layers/picture_layer.cc b/cc/layers/picture_layer.cc
index 8ed4c8b768a36055971a4d5a1da27b8d7efeadf8..7299ee8e030ef69fe70d12a9d47f9db3cc735710 100644
--- a/cc/layers/picture_layer.cc
+++ b/cc/layers/picture_layer.cc
@@ -16,7 +16,7 @@
#include "cc/proto/layer.pb.h"
#include "cc/trees/layer_tree_host.h"
#include "cc/trees/layer_tree_impl.h"
-#include "third_party/skia/include/core/SkPictureRecorder.h"
+#include "skia/ext/cdl_picture_recorder.h"
#include "ui/gfx/geometry/rect_conversions.h"
namespace cc {
@@ -146,9 +146,9 @@ void PictureLayer::SetIsMask(bool is_mask) {
is_mask_ = is_mask;
}
-sk_sp<SkPicture> PictureLayer::GetPicture() const {
+sk_sp<CdlPicture> PictureLayer::GetPicture() const {
// We could either flatten the RecordingSource into a single
// SkPicture, or paint a fresh one depending on what we intend to do with the
// picture. For now we just paint a fresh one to get consistent results.
if (!DrawsContent())
return nullptr;
@@ -221,8 +221,8 @@ void PictureLayer::ToLayerPropertiesProto(proto::LayerProperties* proto) {
picture_layer_inputs_.display_list->ToProtobuf(
picture->mutable_display_list());
for (const auto& item : *picture_layer_inputs_.display_list) {
- sk_sp<const SkPicture> picture = item.GetPicture();
- // Only DrawingDisplayItems have SkPictures.
+ sk_sp<const CdlPicture> picture = item.GetPicture();
+ // Only DrawingDisplayItems have CdlPictures.
if (!picture)
continue;
« no previous file with comments | « cc/layers/picture_layer.h ('k') | cc/layers/picture_layer_impl_unittest.cc » ('j') | no next file with comments »
@@ -146,9 +146,9 @@ void PictureLayer::SetIsMask(bool is_mask) {
// We could either flatten the RecordingSource into a single
- // SkPicture, or paint a fresh one depending on what we intend to do with the
+ // CdlPicture, or paint a fresh one depending on what we intend to do with the
// picture. For now we just paint a fresh one to get consistent results.
if (!DrawsContent())

Powered by Google App Engine
This is Rietveld 408576698